==> mulify-0.1.0.jar: mulify/ee.clj <==
(ns mulify.ee
  (:require [mulify.doc :as doc]
            [mulify.core :refer (defprocess)]
            [silvur.util :refer [uuid]]
            [clojure.data.xml :as dx]))

(defprocess transform)

;; (defn transform [& body]
;;   (if (:tag (first body))
;;     (apply dx/element ::transform {:doc:id (str (uuid))} body)
;;     (apply dx/element ::transform (conj {:doc:id (str (uuid))} (first body)) (rest body))))

(defprocess message)

;; (defn message [payload]
;;   (dx/element ::message {} payload))


(defprocess object-store-caching-strategy)

;; (defn object-store-caching-strategy [& [{:keys [name]}]]
;;   (dx/element ::object-store-caching-strategy
;;               {:name "object-store-caching-strategy"
;;                :id (str (uuid))}))

(defprocess cache)

;; (defn cache [& [{:keys [name caching-strategy-ref]}]]
;;   (dx/element ::cache
;;               (conj {:name (or name "default-cache")
;;                      :id (str (uuid))}
;;                     (when caching-strategy-ref {:cachingStrategy-ref caching-strategy-ref}))))


(defprocess set-payload {} :update-fn dx/cdata)

;; (defn set-payload [value]
;;   (dx/element ::set-payload
;;               {:doc:name "Set Payload"
;;                :doc:id (str (uuid))}
;;               (dx/cdata value)))

(defprocess set-variable)

;; (defn set-variable [{:keys [variable-name]} value]
;;   (dx/element ::set-variable {:variableName variable-name} value))

(defprocess variables)

;; (defn variables [& vs]
;;   (apply dx/element ::variables {} vs))


;; (defn transform* [body]
;;   (transform
;;    (message
;;     (set-payload body))))

==> mulify-0.2.0.jar: mulify/ee.clj <==
(ns mulify.ee
  (:require [mulify.doc :as doc]
            [mulify.core :refer (defprocess)]
            [silvur.util :refer [uuid]]
            [clojure.data.xml :as dx]))

(defprocess transform {:display-name "transform"})

;; (defn transform [& body]
;;   (if (:tag (first body))
;;     (apply dx/element ::transform {:doc:id (str (uuid))} body)
;;     (apply dx/element ::transform (conj {:doc:id (str (uuid))} (first body)) (rest body))))

(defprocess message)

;; (defn message [payload]
;;   (dx/element ::message {} payload))


(defprocess object-store-caching-strategy)

;; (defn object-store-caching-strategy [& [{:keys [name]}]]
;;   (dx/element ::object-store-caching-strategy
;;               {:name "object-store-caching-strategy"
;;                :id (str (uuid))}))

(defprocess cache)

;; (defn cache [& [{:keys [name caching-strategy-ref]}]]
;;   (dx/element ::cache
;;               (conj {:name (or name "default-cache")
;;                      :id (str (uuid))}
;;                     (when caching-strategy-ref {:cachingStrategy-ref caching-strategy-ref}))))


(defprocess set-payload {} :update-fn dx/cdata)

;; (defn set-payload [value]
;;   (dx/element ::set-payload
;;               {:doc:name "Set Payload"
;;                :doc:id (str (uuid))}
;;               (dx/cdata value)))

(defprocess set-variable)

;; (defn set-variable [{:keys [variable-name]} value]
;;   (dx/element ::set-variable {:variableName variable-name} value))

(defprocess variables)

(defprocess message)

;; (defn variables [& vs]
;;   (apply dx/element ::variables {} vs))


;; (defn transform* [body]
;;   (transform
;;    (message
;;     (set-payload body))))

(defn transform* [& {:keys [display-name resource dw]  :as params} ]
  (transform {:display-name display-name}
   (message {}
    (set-payload (or dw (select-keys params [:resource] ))))))
